@@ -29,6 +29,7 @@ class ObjectManager;
 class AgentManager;
 class ProfileManager;
 class DeviceManager;
+class Media;
 class ObexObject;
 class ObexAgentManager;
 class ObexClient;
@@ -38,7 +39,7 @@ class FakeBluez : public QObject
     Q_OBJECT
 
 public:
-    explicit FakeBluez(QObject *parent = Q_NULLPTR);
+    explicit FakeBluez(QObject *parent = nullptr);
 
     void runTest(const QString &testName);
     void runAction(const QString &object, const QString &actionName, const QVariantMap &properties);
@@ -52,6 +53,7 @@ private:
     void createAgentManager();
     void createProfileManager();
     void createDeviceManager();
+    void createMedia();
     void createObexObjectManager();
     void createObexAgentManager();
     void createObexClient();
@@ -72,6 +74,7 @@ private:
     AgentManager *m_agentManager;
     ProfileManager *m_profileManager;
     DeviceManager *m_deviceManager;
+    Media *m_media;
 
     ObexObject *m_obexObject;
     ObexAgentManager *m_obexAgentManager;
